# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: programme_facetrack.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='programme_facetrack.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\035com.ubtechinc.alpha.programme',
    serialized_pb=b'\n\x19programme_facetrack.proto\x1a\x16\x63odemao_faceinfo.proto\"8\n\x10\x46\x61\x63\x65TrackRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\x12\x13\n\x0bisNeedTrack\x18\x02 \x01(\x08\"`\n\x11\x46\x61\x63\x65TrackResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x1f\n\x1d\x63om.ubtechinc.alpha.programmeb\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_FACETRACKREQUEST = _descriptor.Descriptor(
    name='FaceTrackRequest',
    full_name='FaceTrackRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceTrackRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isNeedTrack', full_name='FaceTrackRequest.isNeedTrack', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=53,
    serialized_end=109,
)

_FACETRACKRESPONSE = _descriptor.Descriptor(
    name='FaceTrackResponse',
    full_name='FaceTrackResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='FaceTrackResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceTrackResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceTrackResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=111,
    serialized_end=207,
)

_FACETRACKRESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['FaceTrackRequest'] = _FACETRACKREQUEST
DESCRIPTOR.message_types_by_name['FaceTrackResponse'] = _FACETRACKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceTrackRequest = _reflection.GeneratedProtocolMessageType('FaceTrackRequest', (_message.Message,), {
    'DESCRIPTOR': _FACETRACKREQUEST,
    '__module__': 'programme_facetrack_pb2'
    # @@protoc_insertion_point(class_scope:FaceTrackRequest)
})
_sym_db.RegisterMessage(FaceTrackRequest)

FaceTrackResponse = _reflection.GeneratedProtocolMessageType('FaceTrackResponse', (_message.Message,), {
    'DESCRIPTOR': _FACETRACKRESPONSE,
    '__module__': 'programme_facetrack_pb2'
    # @@protoc_insertion_point(class_scope:FaceTrackResponse)
})
_sym_db.RegisterMessage(FaceTrackResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_facerecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_facerecognise.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1b\x63odemao_facerecognise.proto\x1a\x16\x63odemao_faceinfo.proto\"\'\n\x14\x46\x61\x63\x65RecogniseRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\"w\n\x15\x46\x61\x63\x65RecogniseResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_FACERECOGNISEREQUEST = _descriptor.Descriptor(
    name='FaceRecogniseRequest',
    full_name='FaceRecogniseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceRecogniseRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=55,
    serialized_end=94,
)

_FACERECOGNISERESPONSE = _descriptor.Descriptor(
    name='FaceRecogniseResponse',
    full_name='FaceRecogniseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='FaceRecogniseResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceRecogniseResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceRecogniseResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceRecogniseResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=96,
    serialized_end=215,
)

_FACERECOGNISERESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['FaceRecogniseRequest'] = _FACERECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['FaceRecogniseResponse'] = _FACERECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceRecogniseRequest = _reflection.GeneratedProtocolMessageType('FaceRecogniseRequest', (_message.Message,), {
    'DESCRIPTOR': _FACERECOGNISEREQUEST,
    '__module__': 'codemao_facerecognise_pb2'
    # @@protoc_insertion_point(class_scope:FaceRecogniseRequest)
})
_sym_db.RegisterMessage(FaceRecogniseRequest)

FaceRecogniseResponse = _reflection.GeneratedProtocolMessageType('FaceRecogniseResponse', (_message.Message,), {
    'DESCRIPTOR': _FACERECOGNISERESPONSE,
    '__module__': 'codemao_facerecognise_pb2'
    # @@protoc_insertion_point(class_scope:FaceRecogniseResponse)
})
_sym_db.RegisterMessage(FaceRecogniseResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_translate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudtranslate_pb2 as cloudtranslate__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_translate.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x17\x63odemao_translate.proto\x1a\x14\x63loudtranslate.proto\"1\n\x10TranslateRequest\x12\x1d\n\ttranslate\x18\x01 \x01(\x0b\x32\n.Translate\":\n\x11TranslateResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudtranslate__pb2.DESCRIPTOR, ])

_TRANSLATEREQUEST = _descriptor.Descriptor(
    name='TranslateRequest',
    full_name='TranslateRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='translate', full_name='TranslateRequest.translate', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=49,
    serialized_end=98,
)

_TRANSLATERESPONSE = _descriptor.Descriptor(
    name='TranslateResponse',
    full_name='TranslateResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='TranslateResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='TranslateResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=100,
    serialized_end=158,
)

_TRANSLATEREQUEST.fields_by_name['translate'].message_type = cloudtranslate__pb2._TRANSLATE
DESCRIPTOR.message_types_by_name['TranslateRequest'] = _TRANSLATEREQUEST
DESCRIPTOR.message_types_by_name['TranslateResponse'] = _TRANSLATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TranslateRequest = _reflection.GeneratedProtocolMessageType('TranslateRequest', (_message.Message,), {
    'DESCRIPTOR': _TRANSLATEREQUEST,
    '__module__': 'codemao_translate_pb2'
    # @@protoc_insertion_point(class_scope:TranslateRequest)
})
_sym_db.RegisterMessage(TranslateRequest)

TranslateResponse = _reflection.GeneratedProtocolMessageType('TranslateResponse', (_message.Message,), {
    'DESCRIPTOR': _TRANSLATERESPONSE,
    '__module__': 'codemao_translate_pb2'
    # @@protoc_insertion_point(class_scope:TranslateResponse)
})
_sym_db.RegisterMessage(TranslateResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import enum

from ..blockapi.base_api import BaseBlockApi, DEFAULT_TIMEOUT
from ..blockapi.cmdid import PCProgramCmdId
from ..pb2.codemao_controlbehavior_pb2 import ControlBehaviorRequest, ControlBehaviorResponse
from ..pb2.codemao_controlmouthlamp_pb2 import ControlMouthRequest, ControlMouthResponse
from ..pb2.codemao_playexpression_pb2 import PlayExpressionRequest, PlayExpressionResponse
from ..pb2.codemao_setmouthlamp_pb2 import SetMouthLampRequest, SetMouthLampResponse
from ..pb2.pccodemao_message_pb2 import Message


@enum.unique
class RobotExpressionType(enum.Enum):
    INNER = 0  # 内置表情
    CUSTOM = 1  # 自定义表情


class PlayExpression(BaseBlockApi):
    """
    播放表情
    express_name:表情名称
    express_type: 表情类型，默认内置表情
    """

    def __init__(self, is_serial: bool = True, express_name: str = None,
                 express_type: RobotExpressionType = RobotExpressionType.INNER):
        assert express_name is not None, 'PlayExpression expressName could not be None'
        self.__isSerial = is_serial
        self.__expressName = express_name
        self.__dirType = express_type.value

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = PlayExpressionRequest()
        request.expressName = self.__expressName
        request.dirType = self.__dirType

        cmd_id: int = PCProgramCmdId.PLAY_EXPRESSION_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = PlayExpressionResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotBehaviorControlType(enum.Enum):
    START = 1  # 开始
    STOP = 0  # 停止


class ControlBehavior(BaseBlockApi):
    """
    控制表现力
    name:表现力名称
    control_type: 控制类型，默认为开始
    """

    def __init__(self, is_serial: bool = True, name: str = None,
                 control_type: RobotBehaviorControlType = RobotBehaviorControlType.START):
        assert name is not None and len(name), 'ControlBehavior name should be available'
        self.__isSerial = is_serial
        self.__name = name
        self.__eventType = control_type.value

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlBehaviorRequest()
        request.name = self.__name
        request.eventType = self.__eventType

        cmd_id = PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlBehaviorResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class MouthLampColor(enum.Enum):
    RED = 1  # 红色
    GREEN = 2  # 绿色
    BLUE = 3  # 蓝色


class SetMouthLamp(BaseBlockApi):
    """
    设置嘴巴灯
    TODO:各参数的范围和意义
    color：嘴巴灯颜色
    """

    def __init__(self, is_serial: bool = True, model: int = 0, color: MouthLampColor = MouthLampColor.RED,
                 duration: int = 0,
                 breath_duration: int = 0):

        self.__isSerial = is_serial
        self.__model = model
        self.__color = color.value
        self.__duration = duration
        self.__breathDuration = breath_duration

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = SetMouthLampRequest()
        request.model = self.__model
        request.color = self.__color
        request.duration = self.__duration
        request.breathDuration = self.__breathDuration

        cmd_id = PCProgramCmdId.SET_MOUTH_LAMP_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = SetMouthLampResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class ControlMouthLamp(BaseBlockApi):
    """
    控制嘴巴灯开关
    is_open：默认true，开启嘴巴灯
    """

    def __init__(self, is_serial: bool = True, is_open: bool = True):

        self.__isSerial = is_serial
        self.__isOpen = is_open

    async def execute(self):
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = ControlMouthRequest()
        request.isOpen = self.__isOpen

        cmd_id = PCProgramCmdId.SWITCH_MOUTH_LAMP_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def parse_msg(self, message):
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlMouthResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloudstorageurls.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cloudstorageurls.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x16\x63loudstorageurls.proto\"3\n\x0c\x43loudStorage\x12\x0b\n\x03url\x18\x01 \x03(\t\x12\x16\n\x04type\x18\x02 \x01(\x0e\x32\x08.UrlType*g\n\x07UrlType\x12\x11\n\rQINIU_PRIVATE\x10\x00\x12\x12\n\x0e\x41LIYUN_PRIVATE\x10\x01\x12\x0e\n\nNET_PUBLIC\x10\x02\x12\x10\n\x0cPRESET_LOCAL\x10\x03\x12\x13\n\x0f\x43USTOMIZE_LOCAL\x10\x04\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_URLTYPE = _descriptor.EnumDescriptor(
    name='UrlType',
    full_name='UrlType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='QINIU_PRIVATE', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ALIYUN_PRIVATE', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NET_PUBLIC', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='PRESET_LOCAL', index=3, number=3,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CUSTOMIZE_LOCAL', index=4, number=4,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=79,
    serialized_end=182,
)
_sym_db.RegisterEnumDescriptor(_URLTYPE)

UrlType = enum_type_wrapper.EnumTypeWrapper(_URLTYPE)
QINIU_PRIVATE = 0
ALIYUN_PRIVATE = 1
NET_PUBLIC = 2
PRESET_LOCAL = 3
CUSTOMIZE_LOCAL = 4

_CLOUDSTORAGE = _descriptor.Descriptor(
    name='CloudStorage',
    full_name='CloudStorage',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='url', full_name='CloudStorage.url', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='type', full_name='CloudStorage.type', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=77,
)

_CLOUDSTORAGE.fields_by_name['type'].enum_type = _URLTYPE
DESCRIPTOR.message_types_by_name['CloudStorage'] = _CLOUDSTORAGE
DESCRIPTOR.enum_types_by_name['UrlType'] = _URLTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CloudStorage = _reflection.GeneratedProtocolMessageType('CloudStorage', (_message.Message,), {
    'DESCRIPTOR': _CLOUDSTORAGE,
    '__module__': 'cloudstorageurls_pb2'
    # @@protoc_insertion_point(class_scope:CloudStorage)
})
_sym_db.RegisterMessage(CloudStorage)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloudtranslate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cloudtranslate.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x14\x63loudtranslate.proto\"\x8f\x01\n\tTranslate\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\x12\x1b\n\x08platform\x18\x04 \x01(\x0e\x32\t.Platform\x12\x1b\n\x04\x66rom\x18\x05 \x01(\x0e\x32\r.LanguageType\x12\x19\n\x02to\x18\x06 \x01(\x0e\x32\r.LanguageType*\xde\x02\n\x0cLanguageType\x12\x06\n\x02\x43N\x10\x00\x12\x06\n\x02\x45N\x10\x01\x12\x06\n\x02TW\x10\x02\x12\x06\n\x02\x46R\x10\x03\x12\x06\n\x02\x44\x45\x10\x04\x12\x06\n\x02\x45L\x10\x05\x12\x06\n\x02JA\x10\x06\x12\x06\n\x02KO\x10\x07\x12\x06\n\x02RU\x10\x08\x12\x06\n\x02\x43S\x10\t\x12\x06\n\x02\x44\x41\x10\n\x12\x06\n\x02NL\x10\x0b\x12\x06\n\x02\x46I\x10\x0c\x12\x06\n\x02\x42N\x10\r\x12\x06\n\x02\x41\x46\x10\x0e\x12\x06\n\x02\x45U\x10\x0f\x12\x06\n\x02\x42G\x10\x10\x12\x06\n\x02\x42\x45\x10\x11\x12\x06\n\x02\x45O\x10\x12\x12\x06\n\x02ID\x10\x13\x12\x06\n\x02IT\x10\x14\x12\x06\n\x02GA\x10\x15\x12\x06\n\x02KY\x10\x16\x12\x06\n\x02LA\x10\x17\x12\x06\n\x02LO\x10\x18\x12\x06\n\x02MS\x10\x19\x12\x06\n\x02NO\x10\x1a\x12\x06\n\x02\x46\x41\x10\x1b\x12\x06\n\x02PT\x10\x1c\x12\x06\n\x02SR\x10\x1d\x12\x06\n\x02SO\x10\x1e\x12\x06\n\x02UZ\x10\x1f\x12\x06\n\x02ZU\x10 \x12\x06\n\x02YO\x10!\x12\x06\n\x02VI\x10\"\x12\x06\n\x02TH\x10#\x12\x06\n\x02TG\x10$\x12\x06\n\x02SK\x10%\x12\x06\n\x02\x41R\x10&\x12\x06\n\x02MN\x10\'\x12\x06\n\x02MY\x10(\x12\x06\n\x02TL\x10)*.\n\x08Platform\x12\t\n\x05\x42\x41IDU\x10\x00\x12\x0b\n\x07TENCENT\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_LANGUAGETYPE = _descriptor.EnumDescriptor(
    name='LanguageType',
    full_name='LanguageType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='CN', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='EN', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TW', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='FR', index=3, number=3,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='DE', index=4, number=4,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='EL', index=5, number=5,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='JA', index=6, number=6,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='KO', index=7, number=7,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='RU', index=8, number=8,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='CS', index=9, number=9,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='DA', index=10, number=10,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NL', index=11, number=11,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='FI', index=12, number=12,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='BN', index=13, number=13,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='AF', index=14, number=14,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='EU', index=15, number=15,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='BG', index=16, number=16,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='BE', index=17, number=17,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='EO', index=18, number=18,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ID', index=19, number=19,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='IT', index=20, number=20,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='GA', index=21, number=21,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='KY', index=22, number=22,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='LA', index=23, number=23,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='LO', index=24, number=24,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='MS', index=25, number=25,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NO', index=26, number=26,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='FA', index=27, number=27,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='PT', index=28, number=28,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SR', index=29, number=29,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SO', index=30, number=30,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='UZ', index=31, number=31,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ZU', index=32, number=32,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='YO', index=33, number=33,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='VI', index=34, number=34,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TH', index=35, number=35,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TG', index=36, number=36,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SK', index=37, number=37,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='AR', index=38, number=38,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='MN', index=39, number=39,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='MY', index=40, number=40,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TL', index=41, number=41,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=171,
    serialized_end=521,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGETYPE)

LanguageType = enum_type_wrapper.EnumTypeWrapper(_LANGUAGETYPE)
_PLATFORM = _descriptor.EnumDescriptor(
    name='Platform',
    full_name='Platform',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='BAIDU', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='TENCENT', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='GOOGLE', index=2, number=2,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=523,
    serialized_end=569,
)
_sym_db.RegisterEnumDescriptor(_PLATFORM)

Platform = enum_type_wrapper.EnumTypeWrapper(_PLATFORM)
CN = 0
EN = 1
TW = 2
FR = 3
DE = 4
EL = 5
JA = 6
KO = 7
RU = 8
CS = 9
DA = 10
NL = 11
FI = 12
BN = 13
AF = 14
EU = 15
BG = 16
BE = 17
EO = 18
ID = 19
IT = 20
GA = 21
KY = 22
LA = 23
LO = 24
MS = 25
NO = 26
FA = 27
PT = 28
SR = 29
SO = 30
UZ = 31
ZU = 32
YO = 33
VI = 34
TH = 35
TG = 36
SK = 37
AR = 38
MN = 39
MY = 40
TL = 41
BAIDU = 0
TENCENT = 1
GOOGLE = 2

_TRANSLATE = _descriptor.Descriptor(
    name='Translate',
    full_name='Translate',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='query', full_name='Translate.query', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='prefix', full_name='Translate.prefix', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='suffix', full_name='Translate.suffix', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='platform', full_name='Translate.platform', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='from', full_name='Translate.from', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='to', full_name='Translate.to', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=25,
    serialized_end=168,
)

_TRANSLATE.fields_by_name['platform'].enum_type = _PLATFORM
_TRANSLATE.fields_by_name['from'].enum_type = _LANGUAGETYPE
_TRANSLATE.fields_by_name['to'].enum_type = _LANGUAGETYPE
DESCRIPTOR.message_types_by_name['Translate'] = _TRANSLATE
DESCRIPTOR.enum_types_by_name['LanguageType'] = _LANGUAGETYPE
DESCRIPTOR.enum_types_by_name['Platform'] = _PLATFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Translate = _reflection.GeneratedProtocolMessageType('Translate', (_message.Message,), {
    'DESCRIPTOR': _TRANSLATE,
    '__module__': 'cloudtranslate_pb2'
    # @@protoc_insertion_point(class_scope:Translate)
})
_sym_db.RegisterMessage(Translate)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_playonlinemusic.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudtranslate_pb2 as cloudtranslate__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_playonlinemusic.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x1d\x63odemao_playonlinemusic.proto\x1a\x14\x63loudtranslate.proto\"9\n\x0cMusicRequest\x12\x1b\n\x08platform\x18\x01 \x01(\x0e\x32\t.Platform\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n\rMusicResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudtranslate__pb2.DESCRIPTOR, ])

_MUSICREQUEST = _descriptor.Descriptor(
    name='MusicRequest',
    full_name='MusicRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='platform', full_name='MusicRequest.platform', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='name', full_name='MusicRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=55,
    serialized_end=112,
)

_MUSICRESPONSE = _descriptor.Descriptor(
    name='MusicResponse',
    full_name='MusicResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='MusicResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='MusicResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=114,
    serialized_end=168,
)

_MUSICREQUEST.fields_by_name['platform'].enum_type = cloudtranslate__pb2._PLATFORM
DESCRIPTOR.message_types_by_name['MusicRequest'] = _MUSICREQUEST
DESCRIPTOR.message_types_by_name['MusicResponse'] = _MUSICRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MusicRequest = _reflection.GeneratedProtocolMessageType('MusicRequest', (_message.Message,), {
    'DESCRIPTOR': _MUSICREQUEST,
    '__module__': 'codemao_playonlinemusic_pb2'
    # @@protoc_insertion_point(class_scope:MusicRequest)
})
_sym_db.RegisterMessage(MusicRequest)

MusicResponse = _reflection.GeneratedProtocolMessageType('MusicResponse', (_message.Message,), {
    'DESCRIPTOR': _MUSICRESPONSE,
    '__module__': 'codemao_playonlinemusic_pb2'
    # @@protoc_insertion_point(class_scope:MusicResponse)
})
_sym_db.RegisterMessage(MusicResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_observevolumekeypress.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_observevolumekeypress.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n#codemao_observevolumekeypress.proto\"3\n\x1cObserveVolumeKeyPressRequest\x12\x13\n\x0bisSubscribe\x18\x01 \x01(\x08\"-\n\x1dObserveVolumeKeyPressResponse\x12\x0c\n\x04type\x18\x01 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_OBSERVEVOLUMEKEYPRESSREQUEST = _descriptor.Descriptor(
    name='ObserveVolumeKeyPressRequest',
    full_name='ObserveVolumeKeyPressRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSubscribe', full_name='ObserveVolumeKeyPressRequest.isSubscribe', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=39,
    serialized_end=90,
)

_OBSERVEVOLUMEKEYPRESSRESPONSE = _descriptor.Descriptor(
    name='ObserveVolumeKeyPressResponse',
    full_name='ObserveVolumeKeyPressResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='ObserveVolumeKeyPressResponse.type', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=92,
    serialized_end=137,
)

DESCRIPTOR.message_types_by_name['ObserveVolumeKeyPressRequest'] = _OBSERVEVOLUMEKEYPRESSREQUEST
DESCRIPTOR.message_types_by_name['ObserveVolumeKeyPressResponse'] = _OBSERVEVOLUMEKEYPRESSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObserveVolumeKeyPressRequest = _reflection.GeneratedProtocolMessageType('ObserveVolumeKeyPressRequest',
                                                                        (_message.Message,), {
                                                                            'DESCRIPTOR': _OBSERVEVOLUMEKEYPRESSREQUEST,
                                                                            '__module__': 'codemao_observevolumekeypress_pb2'
                                                                            # @@protoc_insertion_point(class_scope:ObserveVolumeKeyPressRequest)
                                                                        })
_sym_db.RegisterMessage(ObserveVolumeKeyPressRequest)

ObserveVolumeKeyPressResponse = _reflection.GeneratedProtocolMessageType('ObserveVolumeKeyPressResponse',
                                                                         (_message.Message,), {
                                                                             'DESCRIPTOR': _OBSERVEVOLUMEKEYPRESSRESPONSE,
                                                                             '__module__': 'codemao_observevolumekeypress_pb2'
                                                                             # @@protoc_insertion_point(class_scope:ObserveVolumeKeyPressResponse)
                                                                         })
_sym_db.RegisterMessage(ObserveVolumeKeyPressResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_facerecognisetask.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_facerecognisetask.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1f\x63odemao_facerecognisetask.proto\x1a\x16\x63odemao_faceinfo.proto\"m\n\x18\x46\x61\x63\x65RecogniseTaskRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\x12\x0e\n\x06period\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x12\x0e\n\x06switch\x18\x04 \x01(\x08\x12\x11\n\tcommandId\x18\x05 \x01(\t\"{\n\x19\x46\x61\x63\x65RecogniseTaskResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_FACERECOGNISETASKREQUEST = _descriptor.Descriptor(
    name='FaceRecogniseTaskRequest',
    full_name='FaceRecogniseTaskRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceRecogniseTaskRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='period', full_name='FaceRecogniseTaskRequest.period', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='delay', full_name='FaceRecogniseTaskRequest.delay', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='switch', full_name='FaceRecogniseTaskRequest.switch', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceRecogniseTaskRequest.commandId', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=59,
    serialized_end=168,
)

_FACERECOGNISETASKRESPONSE = _descriptor.Descriptor(
    name='FaceRecogniseTaskResponse',
    full_name='FaceRecogniseTaskResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='FaceRecogniseTaskResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceRecogniseTaskResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceRecogniseTaskResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceRecogniseTaskResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=170,
    serialized_end=293,
)

_FACERECOGNISETASKRESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['FaceRecogniseTaskRequest'] = _FACERECOGNISETASKREQUEST
DESCRIPTOR.message_types_by_name['FaceRecogniseTaskResponse'] = _FACERECOGNISETASKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceRecogniseTaskRequest = _reflection.GeneratedProtocolMessageType('FaceRecogniseTaskRequest', (_message.Message,), {
    'DESCRIPTOR': _FACERECOGNISETASKREQUEST,
    '__module__': 'codemao_facerecognisetask_pb2'
    # @@protoc_insertion_point(class_scope:FaceRecogniseTaskRequest)
})
_sym_db.RegisterMessage(FaceRecogniseTaskRequest)

FaceRecogniseTaskResponse = _reflection.GeneratedProtocolMessageType('FaceRecogniseTaskResponse', (_message.Message,), {
    'DESCRIPTOR': _FACERECOGNISETASKRESPONSE,
    '__module__': 'codemao_facerecognisetask_pb2'
    # @@protoc_insertion_point(class_scope:FaceRecogniseTaskResponse)
})
_sym_db.RegisterMessage(FaceRecogniseTaskResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
